@@ -5,7 +5,7 @@ use PDF::Class::Type;
 
 role PDF::Field
     does PDF::COS::Tie::Hash
-    does PDF::Class::Type['FT'] {
+    does PDF::Class::Type::Subtyped {
 
     use PDF::COS::Tie;
     use PDF::COS::TextString;
@@ -60,7 +60,8 @@ role PDF::Field
 	PDF::COS.coerce( $dict, $field.field-delegate( $dict ) );
     }
 
-    has FieldTypeName $.FT is entry(:inherit, :alias<field-type>);  # Required for terminal fields; inheritable) The type of field that this dictionary describes
+    method type { 'Field' }
+    has FieldTypeName $.FT is entry(:inherit, :alias<subtype>);  # Required for terminal fields; inheritable) The type of field that this dictionary describes
     has PDF::Field $.Parent is entry(:indirect);      # (Required if this field is the child of another in the field hierarchy; absent otherwise) The field that is the immediate parent of this one (the field, if any, whose Kids array includes this field). A field can have at most one parent; that is, it can be included in the Kids array of at most one other field.
 
     my subset AnnotOrField of Hash where AnnotLike|PDF::Field;
